@@ -19,6 +19,7 @@ from time import strftime, gmtime
 import argparse
 import sys
 import re
+import getpass
 
 
 def d2b(a):
@@ -59,9 +60,14 @@ def convert(low, high, lockout=False):
         minutes = int(strftime("%M", gmtime(tmp)))
         hours = int(strftime("%H", gmtime(tmp)))
         days = int(strftime("%j", gmtime(tmp)))-1
+        years = int(strftime("%Y", gmtime(tmp)))-1970
     except ValueError as e:
         return "[-] Invalid TIME"
 
+    if years > 1:
+        time += "{0} years ".format(years)
+    elif years == 1:
+        time += "{0} year ".format(years)
     if days > 1:
         time += "{0} days ".format(days)
     elif days == 1:
@@ -84,13 +90,14 @@ class SAMRDump:
     }
 
     def __init__(self, protocols=None,
-                 username='', password=''):
+                 username='', password='', hidepwd=False):
         if not protocols:
             protocols = list(SAMRDump.KNOWN_PROTOCOLS.keys())
 
         self.__username = username
         self.__password = password
         self.__protocols = protocols
+        self.__hidepwd = hidepwd
 
     def dump(self, addr):
         """Dumps the list of users and shares registered present at
@@ -98,7 +105,12 @@ class SAMRDump:
         """
 
         print('\n')
-        if (self.__username and self.__password):
+        if (self.__username and self.__password and self.__hidepwd):
+            print('[+] Attaching to {0} using {1}:{2}'.format(addr,
+                                                              self.__username,
+                                                              len(self.__password) * '*'))
+            
+        elif (self.__username and self.__password and not self.__hidepwd):
             print('[+] Attaching to {0} using {1}:{2}'.format(addr,
                                                               self.__username,
                                                               self.__password))
@@ -262,6 +274,7 @@ def main():
     user = args.username
     passw = args.password
     target = args.domain
+    hidepwd = False
 
     if args.enum4linux:
         enum4linux_regex = re.compile('(?:([^@:]*)(?::([^@]*))?@)?(.*)')
@@ -270,10 +283,14 @@ def main():
             passw = passw + '@' + target.rpartition('@')[0]
             target = target.rpartition('@')[2]
 
+    if not passw:
+        hidepwd = True
+        passw = getpass.getpass()
+
     if args.protocols:
-        dumper = SAMRDump(args.protocols, user, passw)
+        dumper = SAMRDump(args.protocols, user, passw, hidepwd=hidepwd)
     else:
-        dumper = SAMRDump(username=user, password=passw)
+        dumper = SAMRDump(username=user, password=passw, hidepwd=hidepwd)
 
     try:
         dumper.dump(target)
